@@ -1,24 +1,18 @@
-use 5.10.1;
+use 5.10.0;
 use strict;
 use warnings;
 
-package #
-        Pod::Weaver::Section::Badges::PluginSearcher;
-
-our $VERSION = '0.0400'; # VERSION
-
-use Moose;
-use Module::Pluggable search_path => ['Badge::Depot::Plugin'], require => 1;
-
 package Pod::Weaver::Section::Badges;
 
-our $VERSION = '0.0400'; # VERSION
 # ABSTRACT: Add (or append) a section with badges
+our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
+our $VERSION = '0.0401';
 
 use Moose;
 use MooseX::AttributeDocumented;
 use Types::Standard -types;
 use namespace::autoclean;
+use Pod::Weaver::Section::Badges::PluginSearcher;
 with qw/
     Pod::Weaver::Role::Section
     Pod::Weaver::Role::AddTextToSection
@@ -75,6 +69,13 @@ has formats => (
     documentation => q{The formats to render the badges for. Comma separated list, not multiple rows.},
     documentation_default => '[]',
 );
+has skip_markdown_if_html => (
+    is => 'ro',
+    isa => Bool,
+    default => 1,
+    documentation => q{Some markdown renderers also renders '=begin html' blocks, which makes it unnecessary to set both html and markdown as output formats. Set this to a false value to produce both blocks.},
+);
+
 has badge_args => (
     is => 'ro',
     isa => HashRef[Str],
@@ -151,7 +152,10 @@ sub weave_section {
     ];
 
     my @output = ();
+    FORMAT:
     foreach my $format (@$formats) {
+        # Optionally skip markdown if we also prints to html
+        next FORMAT if $format->{'name'} eq 'markdown' && $self->find_format(sub { $_ eq 'html'}) && $self->skip_markdown_if_html;
         push @output => @{ $self->render_badges($format, $badge_objects) };
     }
 
@@ -174,11 +178,11 @@ __END__
 
 =head1 NAME
 
-Pod::Weaver::Section::Badges::PluginSearcher - Add (or append) a section with badges
+Pod::Weaver::Section::Badges - Add (or append) a section with badges
 
 =head1 VERSION
 
-Version 0.0400, released 2016-01-27.
+Version 0.0401, released 2016-02-17.
 
 
 
@@ -360,6 +364,36 @@ Which is then injected into the chosen C<section>.
 
 =end markdown
 
+=head2 skip_markdown_if_html
+
+=begin HTML
+
+<table cellpadding="0" cellspacing="0">
+<tr>
+    <td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;"><a href="https://metacpan.org/pod/Types::Standard#Bool">Bool</a></td>
+    <td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;">optional, default: <code>1</code></td>
+    <td style="padding-left: 6px; padding-right: 6px; white-space: nowrap;">read-only</td>
+</tr>
+</table>
+
+<p>Some markdown renderers also renders '=begin html' blocks, which makes it unnecessary to set both html and markdown as output formats. Set this to a false value to produce both blocks.</p>
+
+=end HTML
+
+=begin markdown
+
+<table cellpadding="0" cellspacing="0">
+<tr>
+    <td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;"><a href="https://metacpan.org/pod/Types::Standard#Bool">Bool</a></td>
+    <td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;">optional, default: <code>1</code></td>
+    <td style="padding-left: 6px; padding-right: 6px; white-space: nowrap;">read-only</td>
+</tr>
+</table>
+
+<p>Some markdown renderers also renders '=begin html' blocks, which makes it unnecessary to set both html and markdown as output formats. Set this to a false value to produce both blocks.</p>
+
+=end markdown
+
 =head1 SEE ALSO
 
 =over 4
