@@ -1,14 +1,14 @@
-use 5.10.1;
+use 5.10.0;
 use strict;
 use warnings;
 
 package Pod::Weaver::Section::Badges::Utils;
 
-our $VERSION = '0.0400'; # VERSION
 # ABSTRACT: Some helpers
+our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
+our $VERSION = '0.0401';
 
 use Moose::Role;
-
 use List::AllUtils 'first';
 
 sub get_params_for {
@@ -62,10 +62,8 @@ sub render_badges {
     my $format = shift;  # Dict[ name => Str, before => Maybe[Str], after => Maybe[Str] ]
     my $badges = shift;  # ArrayRef[ ConsumerOf['Badge::Depot'] ]
 
-    my $part_format_name = $format->{'name'} eq 'markdown' ? 'markdown' : uc $format->{'name'};
-
-    my $pod_command_begin = sprintf '=begin %s', $part_format_name;
-    my $pod_command_end   = sprintf '=end %s', $part_format_name;
+    my $pod_command_begin = sprintf '=begin %s', $format->{'name'};
+    my $pod_command_end   = sprintf '=end %s', $format->{'name'};
     my $format_method = sprintf 'to_%s', $format->{'name'};
 
     my @badges_output = ();
@@ -77,7 +75,7 @@ sub render_badges {
     }
     if(@badges_output) {
         push @complete_output => '', $pod_command_begin, '', ;
-        push @complete_output => ($format->{'before'} || '') . join (' ' => @badges_output) . ($format->{'after'} || '');
+        push @complete_output => (($format->{'before'} || ''), join ("\n" => @badges_output), ($format->{'after'} || ''));
         push @complete_output => '', $pod_command_end, '';
     }
     return \@complete_output;
@@ -98,7 +96,7 @@ Pod::Weaver::Section::Badges::Utils - Some helpers
 
 =head1 VERSION
 
-Version 0.0400, released 2016-01-27.
+Version 0.0401, released 2016-02-17.
 
 =head1 SOURCE
 
